# What to find here
This folder contains tests for EspressoDB

* `espressodb_tests/m2mtests` contains tests for many-to-many consistency checks
* `espressodb_tests/pre_save_tests` contains tests for the pre save method
